@@ -36,7 +36,6 @@ typedef bool (*check_idle_t)(void *userdata);
 
 typedef struct Context {
         sd_bus *bus;
-        char *debug_level;
 } Context;
 
 typedef struct MethodResult {
@@ -189,7 +188,6 @@ int interactive_permission_check(sd_bus *bus, const char *action, const char **d
 
 static void context_clear(Context *c) {
         assert(c);
-        free(c->debug_level);
         sd_bus_flush_close_unref(c->bus);
         deinit_module_cfgs();
 }
@@ -265,14 +263,7 @@ static int method_set_debug(sd_bus_message *m, void *userdata, sd_bus_error *err
                         sd_bus_error_setf(error, SD_BUS_ERROR_FAILED, "error,ret=%d",r);
                         ret = r;
                 }
-                if (strcmp(name,"all")==0 && r >= 0) {
-                        free(c->debug_level);
-                        c->debug_level = strdup(level);
-                        if (!c->debug_level) {
-                                sd_bus_error_setf(error, SD_BUS_ERROR_FAILED, "Memory allocation failed");
-                                return -ENOMEM;
-                        }
-                }
+
                 if (reboot == 0)
                         config_module_get_property_reboot(name,&reboot);
                 if (name && strcmp(name,"all")==0) break;
@@ -380,9 +371,7 @@ static int method_set_coredump(sd_bus_message *m, void *userdata, sd_bus_error *
 }
 
 static int method_get_state(sd_bus_message *m, void *userdata, sd_bus_error *error) {
-        Context *c = userdata;
         int r;
-        char *debug_level = NULL;
 
         _cleanup_(sd_bus_message_unrefp) sd_bus_message *reply = NULL;
         _cleanup_strv_free_ char **modules = NULL;
@@ -400,22 +389,18 @@ static int method_get_state(sd_bus_message *m, void *userdata, sd_bus_error *err
                 return r;
 
         for (module = modules; module && *module; module++) {
+                _cleanup_free_ char *debug_level = NULL;
+                const char *real_debug_level;
+
                 r = config_module_get_debug_level_by_type(*module, &debug_level);
                 if (r < 0)
                         return sd_bus_error_setf(error, SD_BUS_ERROR_FAILED, "error get module %s,ret=%d",*module,r);
-                r = sd_bus_message_append(reply,"s",debug_level);
+                if (debug_level && strcmp(debug_level,"on") == 0)
+                        real_debug_level = "debug";
+                else
+                        real_debug_level = debug_level ? debug_level : "unknown";
+                r = sd_bus_message_append(reply,"s",real_debug_level);
 
-                if (strcmp(*module,"all")==0) {
-                        // 将 debug_level 复制到 c->debug_level
-                        free(c->debug_level);
-                        c->debug_level = strdup(debug_level);
-                        if (!c->debug_level) {
-                                sd_bus_error_setf(error, SD_BUS_ERROR_FAILED, "Memory allocation failed");
-                                return -ENOMEM;
-                        }
-                }
-
-                free(debug_level);
                 if (r < 0)
                         return r;
         }
@@ -427,8 +412,19 @@ static int method_get_state(sd_bus_message *m, void *userdata, sd_bus_error *err
 }
 
 static int property_debug_level(sd_bus *bus, const char *path, const char *interface, const char *property, sd_bus_message *reply, void *userdata, sd_bus_error *error) {
-        Context *c = userdata;
-        return sd_bus_message_append(reply, "s", c->debug_level ? c->debug_level : "");
+        _cleanup_free_ char *debug_level = NULL;
+        const char *real_debug_level = "";
+        int r;
+
+        r = config_module_get_debug_level_by_type("all", &debug_level);
+        if (r >= 0 && debug_level) {
+                if (strcmp(debug_level, "on") == 0)
+                        real_debug_level = "debug";
+                else
+                        real_debug_level = debug_level;
+        }
+
+        return sd_bus_message_append(reply, "s", real_debug_level);
 }
 
 /* The vtable of our little object, implements the net.poettering.Calculator interface */
