@@ -8,23 +8,6 @@
 #include <limits.h>
 #include "common.h"
 
-
-//读取一个配置文件所能获取到的一个module的信息
-typedef struct sub_module_cfg
-{
-  char *name;
-  char *shell_cmd;
-} sub_module_cfg;
-
-typedef struct module_cfg
-{
-  char *name;
-  char *type;
-  int reboot;
-  int sub_modules_num;
-  sub_module_cfg **sub_modules;
-} module_cfg;
-
 int config_modules_set_debug_level_by_type(const char* module_type, const char *level);
 int config_modules_set_debug_level_by_types(const char* module_types, const char *level);
 int config_module_set_debug_level_by_module_names(const char *module_names, const char *level);
@@ -33,6 +16,7 @@ int config_module_set_debug_level_by_module_name(const char *module_name, const
 int config_module_install_dbgpkgs_internal(const char *module_name);
 
 int config_module_get_debug_level_by_type(const char *module_type, char **level);
+int config_module_get_debug_level_by_types(const char *module_types, char **levels);
 int config_system_coredump(bool open_coredump);
 
 int config_module_get_property_reboot(const char *name,int *reboot);
@@ -43,7 +27,5 @@ void deinit_module_cfgs();
 char **get_module_names();
 
 bool check_can_install_dbg();
-
-int parse_hook_json_file(char *filename, module_cfg* mdle_cfg);
-
+int config_module_reload_debug_level(void);
 #endif
\ No newline at end of file
